#
# spec file for package python-pypet
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%define         skip_python36 1
%bcond_without  test
Name:           python-pypet
Version:        0.5.1
Release:        2.3
Summary:        Parameter exploration and storage of results for numerical simulations
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/SmokinCaterpillar/pypet
Source:         https://files.pythonhosted.org/packages/source/p/pypet/pypet-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module numpy >= 1.6.1}
BuildRequires:  %{python_module pandas >= 0.15.0}
BuildRequires:  %{python_module scipy >= 0.9.0}
BuildRequires:  %{python_module tables >= 3.1.1}
%endif
Requires:       python-numpy >= 1.6.1
Requires:       python-pandas >= 0.15.0
Requires:       python-scipy >= 0.9.0
Requires:       python-tables >= 3.1.1
Recommends:     python-GitPython >= 0.2.1
Recommends:     python-Sumatra >= 0.7.1
Recommends:     python-dill >= 0.2.1
Recommends:     python-psutil >= 2.0.0
Recommends:     python-scoop >= 0.7.1
BuildArch:      noarch

%python_subpackages

%description
pypet is the Python parameter exploration toolkit. pypet manages
exploration of the parameter space of any numerical simulation in
Python, thereby storing data into HDF5 files. Moreover, pypet offers
a data container which gives access to all parameters and results
from a single source.

%prep
%setup -q -n pypet-%{version}

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
export LANG=en_US.UTF-8
pushd pypet/tests
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -B all_single_core_tests.py
}
%endif

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Sun Feb 14 2021 Dirk Müller <dmueller@suse.com>
- turn off python 3.6 build (no scipy)
* Tue Jun 23 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.5.1
  * Updated package description to automatically convert md to rst for pypi
  * Updated pngpath for Sphinx
- Update to 0.5.0
  * Fix to work with pandas 1.0
  * Fix to work with brian2 2.3
  * Fix to work with Python 3.7 and 3.8
  * Removal `expectedrows` and `filters` option for HDF5Storage.put as this is no longer supported by pandas
* Fri Aug  3 2018 toddrme2178@gmail.com
- Update to 0.4.3
  * DEPR: Removed pandas Panel and Panel4D (see also https://github.com/pandas-dev/pandas/pull/13776)
  * Removed support for Python 3.3 and 3.4
* Fri May 18 2018 jengelh@inai.de
- Don't assume any specific user in the description.
* Thu May 10 2018 toddrme2178@gmail.com
- Update to pypet 0.4.2
  * BUG FIX: Brian2Parameters can now be merged [Issue #50]
- Update to pypet 0.4.1
  * BUG FIX: Fixed slow `f_get_from_all_runs` with run groups
  * More intuitive behaviro for `f_to_dict` to only start at initiating group node.
  * BUG FIX: brian 2 removed get unit fast, this has been replaced with a pypet implementation
- Use license tag
* Sun Aug 27 2017 toddrme2178@gmail.com
- Initial version
